Learn R Programming

Inflongitudinal (version 0.1.0)

Phenobarb: Phenobarb Dataset

Description

This dataset contains longitudinal data on Phenobarbital concentration levels in newborn infants.

Usage

Phenobarb

Arguments

Format

A data frame with 744 observations on the following 7 variables:

Subject

An ordered factor identifying the infant.

Wt

A numeric vector giving the birth weight of the infant (kg).

Apgar

An ordered factor giving the 5-minute Apgar score for the infant. This is an indication of the newborn's health.

ApgarInd

A factor indicating whether the 5-minute Apgar score is < 5 or >= 5.

time

A numeric vector giving the time when the sample is drawn or the drug is administered (hr).

dose

A numeric vector giving the dose of drug administered (\(\mu\) g/kg).

conc

A numeric vector giving the phenobarbital concentration in the serum (\(\mu\) g/L).

Examples

Run this code
data(Phenobarb)
head(Phenobarb)

Run the code above in your browser using DataLab